<?php
/**
 * The Blogging functions and definitions.
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package The Blogging
 */

if ( ! function_exists( 'the_blogging_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function the_blogging_setup() {
	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on The Blogging, use a find and replace
	 * to change 'the-blogging' to the name of your theme in all the template files.
	 */
	load_theme_textdomain( 'the-blogging', get_template_directory() . '/languages');

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );

	/*
	 * Enable support for custom logo.
	 */
	add_theme_support( 'custom-logo', array(
	   'header-text' => array( 'site-title', 'site-description' ),
	) );
	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
	 */
	add_theme_support( 'post-thumbnails' );
	add_image_size( 'the-blogging-main-banner', 1370, 550, true );


	// Set up the WordPress core custom header feature.
	add_theme_support( 'custom-header', apply_filters( 'the_blogging_custom_header_args', array(
			'width'         => 1400,
			'height'        => 380,
			'flex-height'   => true,
			'header-text'   => false,
	) ) );

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
		'top' => esc_html__( 'Top Nav', 'the-blogging' ),
		'primary' => esc_html__( 'Primary', 'the-blogging' ),
		'social'   => esc_html__( 'Social Menu', 'the-blogging' ),
		'footer'   => esc_html__( 'Footer Menu', 'the-blogging' ),
	) );

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'search-form',
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
	) );

	// Set up the WordPress core custom background feature.
	add_theme_support( 'custom-background', apply_filters( 'the_blogging_custom_background_args', array(
		'default-color' => 'ffffff',
		'default-image' => '',
	) ) );

	/*
	 * Enable support for Post Formats.
	 *
	 * See: https://codex.wordpress.org/Post_Formats
	 */
	add_theme_support( 'post-formats', array(
		'video',
		'gallery',
		'audio',
	) );

	if ( class_exists( 'WooCommerce' ) ){
		add_filter( 'woocommerce_get_image_size_gallery_thumbnail', function( $size ) {
		    return array(
		        'width'  => 250,
		        'height' => 250,
		        'crop'   => 0,
		    );
		} );
	}


	/**
	 * Load Init for Hook files.
	 */
	require get_template_directory() . '/inc/hooks/hooks-init.php';


}
endif;
add_action( 'after_setup_theme', 'the_blogging_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function the_blogging_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'the_blogging_content_width', 640 );
}
add_action( 'after_setup_theme', 'the_blogging_content_width', 0 );


/**
 * Enqueue scripts and styles.
 */
function the_blogging_scripts() {
	wp_enqueue_style('ionicons', get_template_directory_uri() . '/assets/libraries/ionicons/css/ionicons.min.css');
	wp_enqueue_style('bootstrap', get_template_directory_uri() . '/assets/libraries/bootstrap/css/bootstrap.min.css');
    wp_enqueue_style('slick', get_template_directory_uri() . '/assets/libraries/slick/css/slick.min.css');
	wp_enqueue_style('magnific-popup', get_template_directory_uri() . '/assets/libraries/magnific-popup/magnific-popup.css');
	wp_enqueue_style( 'the-blogging-style', get_stylesheet_uri() );
    wp_style_add_data('the-blogging-style', 'rtl', 'replace');

    wp_add_inline_style( 'the-blogging-style', the_blogging_trigger_custom_css_action() );
	$theme_version = wp_get_theme()->get( 'Version' );
    $fonts_url = the_blogging_fonts_url();
    if (!empty($fonts_url)) {
        require_once get_theme_file_path( 'assets/twp/css/wptt-webfont-loader.php' );
        wp_enqueue_style(
            'the-blogging-google-fonts',
            wptt_get_webfont_url( $fonts_url ),
            array(),
            $theme_version
        );
    }

	wp_enqueue_script( 'the-blogging-navigation', get_template_directory_uri() . '/js/navigation.js', array(), '20151215', true );

	wp_enqueue_script( 'the-blogging-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array(), '20151215', true );

	wp_enqueue_script('jquery-bootstrap', get_template_directory_uri() . '/assets/libraries/bootstrap/js/bootstrap.min.js', array('jquery'), '', true);
    wp_enqueue_script('jquery-slick', get_template_directory_uri() . '/assets/libraries/slick/js/slick.min.js', array('jquery'), '', true);
	wp_enqueue_script('jquery-magnific-popup', get_template_directory_uri() . '/assets/libraries/magnific-popup/jquery.magnific-popup.min.js', array('jquery'), '', true);
	wp_enqueue_script('theiaStickySidebar', get_template_directory_uri() . '/assets/libraries/theiaStickySidebar/theia-sticky-sidebar.min.js', array('jquery'), '', true);
	wp_enqueue_script('the-blogging-script', get_template_directory_uri() . '/assets/twp/js/custom-script.js', array('jquery'), '', 1);
    
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'the_blogging_scripts' );

/**
 * Enqueue admin scripts and styles.
 */
function the_blogging_admin_scripts( $hook ) {
	wp_enqueue_media();
	wp_enqueue_script( 'the-blogging-admin', get_template_directory_uri() . '/assets/twp/js/admin.js', array( 'jquery' ), '1.0.0', true );
	wp_enqueue_style( 'the-blogging-custom-admin-style', get_template_directory_uri() . '/assets/twp/css/wp-admin.css', array(), '1.0.0' );

	$ajax_nonce = wp_create_nonce('the_blogging__ajax_nonce');
        
    wp_localize_script( 
        'the-blogging-admin', 
        'the_blogging__admin',
        array(
            'ajax_url'   => esc_url( admin_url( 'admin-ajax.php' ) ),
            'ajax_nonce' => $ajax_nonce,
            'active' => esc_html__('Active','the-blogging'),
            'deactivate' => esc_html__('Deactivate','the-blogging'),
            'upload_image'   =>  esc_html__('Choose Image','the-blogging'),
            'use_imahe'   =>  esc_html__('Select','the-blogging'),
         )
    );

}
add_action( 'admin_enqueue_scripts', 'the_blogging_admin_scripts' );

/**
 * Add featured image as background image to post navigation elements.
 *
 * @since the-blogging 1.0
 *
 */
function the_blogging_post_nav_background() {
    if ( ! is_single() ) {
        return;
    }

    $previous = ( is_attachment() ) ? get_post( get_post()->post_parent ) : get_adjacent_post( false, '', true );
    $next     = get_adjacent_post( false, '', false );
    $css      = '';

    if ( is_attachment() && 'attachment' == $previous->post_type ) {
        return;
    }

    if ( $previous &&  has_post_thumbnail( $previous->ID ) ) {
        $prevthumb = wp_get_attachment_image_src( get_post_thumbnail_id( $previous->ID ), 'post-thumbnail' );
        $prevthumb = isset( $prevthumb[0] ) ? $prevthumb[0] : '';
        $css .= '
			.post-navigation .nav-previous { background-image: url(' . esc_url( $prevthumb ) . '); }
			.single .post-navigation .nav-previous a:before { background-color: rgba(0, 0, 0, 0.4); }
		';
    }

    if ( $next && has_post_thumbnail( $next->ID ) ) {
        $nextthumb = wp_get_attachment_image_src( get_post_thumbnail_id( $next->ID ), 'post-thumbnail' );
        $nextthumb = isset( $nextthumb[0] ) ? $nextthumb[0] : '';
        $css .= '
			.post-navigation .nav-next { background-image: url(' . esc_url( $nextthumb ) . '); border-top: 0; }
			.single .post-navigation .nav-next a:before { background-color: rgba(0, 0, 0, 0.4); }
		';
    }

    wp_add_inline_style( 'the-blogging-style', $css );
}
add_action( 'wp_enqueue_scripts', 'the_blogging_post_nav_background' );

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/inc/jetpack.php';
require get_template_directory() . '/classes/about.php';
require get_template_directory() . '/classes/admin-notice.php';
require get_template_directory() . '/classes/plugins-classes.php';
/**
 * Load WooCommerce compatibility file.
 */
if ( class_exists( 'WooCommerce' ) ) {
    require get_template_directory() . '/inc/woocommerce.php';
}

add_filter( 'walker_nav_menu_start_el', 'the_blogging_add_description', 10, 2 );
function the_blogging_add_description( $item_output, $item ) {
    $description = $item->post_content;
    if (('' !== $description) && (' ' !== $description) ) {
        return preg_replace( '/(<a.*)</', '$1' . '<span class="menu-description">' . $description . '</span><', $item_output) ;
    }
    else {
        return $item_output;
    };
}

add_filter('wp_nav_menu_items', 'the_blogging_add_admin_link', 1, 2);
function the_blogging_add_admin_link($items, $args){
    if( $args->theme_location == 'primary' ){
        $item = '<li class="brand-home"><a title="Home" href="'. esc_url( home_url() ) .'">' . "<span class='icon ion-ios-home'></span>" . '</a></li>';
        $items = $item . $items;
    }
    return $items;
}

add_filter('themeinwp_enable_demo_import_compatiblity','the_blogging_demo_import_filter_apply');

if( !function_exists('the_blogging_demo_import_filter_apply') ):

    function the_blogging_demo_import_filter_apply(){

        return true;

    }

endif;